@@ -8,6 +8,11 @@ ssm = session.client(
     service_name='ssm',
 )
 
+_ssm_resource_type = {
+    'String': 'parameter',
+    'SecureString': 'secret',
+    'StringList': 'template',
+}
 ###--------------------------------------------------------------------------------------------
 
 def get_ssm_path(project, application, stage, key=None, prefix=None):
@@ -17,11 +22,11 @@ def get_ssm_path(project, application, stage, key=None, prefix=None):
 
 def load_ssm_path(parameters, path, parameter_type, prefix=None, decrypt=False):
     p = ssm.get_paginator('get_parameters_by_path')
-    paginator = p.paginate(Path=path, Recursive=True, WithDecryption=decrypt, ParameterFilters=[{'Key': 'Type', 'Values': parameter_type}]).build_full_result()
+    paginator = p.paginate(Path=path, Recursive=True, WithDecryption=decrypt, ParameterFilters=[{'Key': 'Type', 'Values': [parameter_type]}]).build_full_result()
     for parameter in paginator['Parameters']:
         key = parameter['Name'][len(path)+1:]
         if key in parameters:
-            Logger.warn("Inherited parameter '{0}' overridden.".format(key))
+            Logger.warn("Inherited {0} '{1}' overridden.".format(_ssm_resource_type[parameter_type] , key))
         
         parameters[key] = {
                             'Value': parameter['Value'], 
