@@ -263,8 +263,8 @@ def read_data(input, parent_key, keys, format):
 
 def validate_only_one_provided(values, names, causes=[]):
 
-    test = reduce(lambda x, y: bool(x) != bool(y), values)
-    if not test:
+    test = not reduce(lambda x, y: bool(x) != bool(y), values)
+    if test:
         Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsOnlyOneProvidedBecause'].format(', '.join(causes), ', '.join(names)))
@@ -276,10 +276,26 @@ def validate_only_one_provided(values, names, causes=[]):
 
 ###--------------------------------------------------------------------------------------------
 
-def validate_not_all_provided(values, names, causes=[]):
+### opposite validate_not_all_provided
+def validate_all_provided(values, names, causes=[]):
 
     test = not reduce(lambda x, y: bool(x) and bool(y), values)
-    if not test:
+    if test:
+        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+        if causes:
+            raise DSOException(CLI_MESSAGES['ArgumentsAllProvidedBecause'].format(', '.join(causes), ', '.join(names)))
+        else:
+            raise DSOException(CLI_MESSAGES['ArgumentsAllProvided'].format(', '.join(names)))
+    
+    # return list(filter(lambda i: not bool(values[i]), range(len(values))))
+
+###--------------------------------------------------------------------------------------------
+
+### opposite validate_all_provided
+def validate_not_all_provided(values, names, causes=[]):
+
+    test = reduce(lambda x, y: bool(x) and bool(y), values)
+    if test:
         Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsNotAllProvidedBecause'].format(', '.join(causes), ', '.join(names)))
@@ -291,21 +307,7 @@ def validate_not_all_provided(values, names, causes=[]):
 
 ###--------------------------------------------------------------------------------------------
 
-def validate_at_least_one_provided(values, names, causes=[]):
-
-    test = reduce(lambda x, y: bool(x) or bool(y), values)
-    if not test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
-        if causes:
-            raise DSOException(CLI_MESSAGES['ArgumentsAtLeastOneProvidedBecause'].format(', '.join(causes), ', '.join(names)))
-        else:
-            raise DSOException(CLI_MESSAGES['ArgumentsAtLeastOneProvided'].format(', '.join(names)))
-
-
-    return reduce(lambda x, y: x or y, values)
-
-###--------------------------------------------------------------------------------------------
-
+### opposite validate_at_least_one_provided
 def validate_none_provided(values, names, causes=[]):
 
     test = reduce(lambda x, y: bool(x) or bool(y), values)
@@ -321,17 +323,19 @@ def validate_none_provided(values, names, causes=[]):
 
 ###--------------------------------------------------------------------------------------------
 
-def validate_all_provided(values, names, causes=[]):
+### opposite validate_none_provided
+def validate_at_least_one_provided(values, names, causes=[]):
 
-    test = reduce(lambda x, y: bool(x) and bool(y), values)
-    if not test:
+    test = not reduce(lambda x, y: bool(x) or bool(y), values)
+    if test:
         Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
         if causes:
-            raise DSOException(CLI_MESSAGES['ArgumentsAllProvidedBecause'].format(', '.join(causes), ', '.join(names)))
+            raise DSOException(CLI_MESSAGES['ArgumentsAtLeastOneProvidedBecause'].format(', '.join(causes), ', '.join(names)))
         else:
-            raise DSOException(CLI_MESSAGES['ArgumentsAllProvided'].format(', '.join(names)))
-    
-    # return list(filter(lambda i: not bool(values[i]), range(len(values))))
+            raise DSOException(CLI_MESSAGES['ArgumentsAtLeastOneProvided'].format(', '.join(names)))
+
+
+    return reduce(lambda x, y: x or y, values)
 
 ###--------------------------------------------------------------------------------------------
 
