@@ -170,10 +170,10 @@ class ConfigManager:
         _config = {}
         if context == 'global':
             _config['project'] = 'default'
-            Logger.warn("Switched to the global context.")
+            Logger.warn("Switched from the application context to the global context.")
         elif context == 'project':
             _config['application'] = 'default'
-            Logger.warn(f"Switched to project context '{self.project}'.")
+            Logger.warn(f"Switched from the application context to the project context '{self.project}'.")
         elif context == 'application':
             pass
         return merge_dicts(self.config_string_to_dict(config_overrides_string), _config)
