@@ -12,7 +12,7 @@ MESSAGES = {
     'InvalidKeyStr': "'{0}' is an invalid key. Cannot contain '{1}'.",
     'ParameterNotFound': "Parameter '{0}' not found in the given context.",
     'SecretNotFound': "Secret '{0}' not found in the given context.",
-    'InvalidStage': "'{0}' is not a valid stage name. Valid form is <string>[/number], where it must conform to '{1}'.",
+    'InvalidStage': "'{0}' is not a valid stage name. The valid form is <string>[/number], where it must conform to '{1}'.",
     'ContextNotFound': "Context '{0}' not found.",
     'PatternNotMatched': "'{0}' is invalid. Must conform to '{1}'",
     'InvalidParameterKeyValuePair': "'{0}' is an invalid parameter key/value pair. Must conform to '^([a-zA-Z][a-zA-Z0-9_.-/]*)=(.*)$'",
@@ -30,6 +30,4 @@ MESSAGES = {
     'DSOConfigurationNotFound': 'DSO configuration not found.',
     'NoDSOConfigFound': "No DSO configuration found in the working directory.",
     'EnteredSecretValuesNotMatched': "Entered values for the secret did not macth.",
-    'QueryOptionCompatibleFormats': "Option '-q' / '--query' can be used only with 'json'/'yaml' output formats.",
-    'QueryAllOptionNonCompatibleFormats': "Option '-a'/ '--query-all' cannot be used with 'shell' output format.",
 }
