@@ -8,16 +8,16 @@ from .exceptions import *
 
 
 class ParameterProvider(StoreProvider):
-    def add(self, project, application, stage, key, value):
+    def list(self, project, application, stage, uninherited=False, filter=None):
         raise NotImplementedError()
-    def list(self, project, application, stage, uninherited):
+    def add(self, project, application, stage, key, value):
         raise NotImplementedError()
     def get(self, project, application, stage, key, revision=None):
         raise NotImplementedError()
-    def delete(self, project, application, stage, key):
-        raise NotImplementedError()
     def history(self, project, application, stage, key):
         raise NotImplementedError()
+    def delete(self, project, application, stage, key):
+        raise NotImplementedError()
 
 
 class ParameterManager():
@@ -31,18 +31,20 @@ class ParameterManager():
         if '..' in key:
             raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
             
-    def list(self, stage, uninherited):
+    def list(self, stage, uninherited=False, filter=None):
         project = Configs.project
         application = Configs.application
+        stage = Stages.normalize(stage)
         provider = Providers.ParameterProvider()
         Logger.info(f"Start listing SSM parameters: project={project}, application={application}, stage={Stages.shorten(stage)}")
-        return provider.list(project, application, stage, uninherited)
+        return provider.list(project, application, stage, uninherited, filter)
 
     def add(self, stage, key, value):
         self.validate_key(key)
         project = Configs.project
         application = Configs.application
-        Logger.info(f"Start adding parameter: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}, value={value}")
+        stage = Stages.normalize(stage)
+        Logger.info(f"Start adding parameter '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         provider = Providers.ParameterProvider()
         return provider.add(project, application, stage, key, value)
 
@@ -50,24 +52,27 @@ class ParameterManager():
         # self.validate_key(key)
         project = Configs.project
         application = Configs.application
+        stage = Stages.normalize(stage)
         provider = Providers.ParameterProvider()
-        Logger.info(f"Start getting parameter value: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        Logger.info(f"Start getting the value of parameter '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         return provider.get(project, application, stage, key, revision)
 
     def history(self, stage, key):
         # self.validate_key(key)
         project = Configs.project
         application = Configs.application
+        stage = Stages.normalize(stage)
         provider = Providers.ParameterProvider()
-        Logger.info(f"Start getting parameter history: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        Logger.info(f"Start getting the history of parameter '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         return provider.history(project, application, stage, key)
 
     def delete(self, stage, key):
         # self.validate_key(key)
         project = Configs.project
         application = Configs.application
+        stage = Stages.normalize(stage)
         provider = Providers.ParameterProvider()
-        Logger.info(f"Start deleting parameter: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        Logger.info(f"Start deleting parameter '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         return provider.delete(project, application, stage, key)
 
 Parameters = ParameterManager()
\ No newline at end of file
