@@ -43,7 +43,7 @@ class AwsSsmSecretProvider(SecretProvider):
 ###--------------------------------------------------------------------------------------------
 
     def list(self, project, application, stage, uninherited=False, decrypt=False, filter=None):
-        secrets = load_context_ssm_parameters(project, application, stage, ['SecureString'], prefix=self.get_prefix(), uninherited=uninherited, decrypt=decrypt)
+        secrets = load_context_ssm_parameters(project, application, stage, 'SecureString', prefix=self.get_prefix(), uninherited=uninherited, decrypt=decrypt)
         result = {'Secrets': []}
         for key, details in secrets.items():
             if filter and not re.match(filter, key): continue
