@@ -52,7 +52,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
 ###--------------------------------------------------------------------------------------------
 
     def list(self, project, application, stage, uninherited=False, include_contents=False, filter=None):
-        templates = load_context_ssm_parameters(project, application, stage, ['StringList'], prefix=self.get_prefix(), uninherited=uninherited)
+        templates = load_context_ssm_parameters(project, application, stage, 'StringList', prefix=self.get_prefix(), uninherited=uninherited)
         result = {'Templates': []}
         for key, details in templates.items():
             if filter and not re.match(filter, key): continue
