@@ -114,9 +114,6 @@ class TemplateManager():
         stage = Stages.normalize(stage)
         Logger.info(f"Start rendering templates: project={project}, application={application}, stage={Stages.shorten(stage)}")
 
-        if Stages.is_default(stage):
-            Logger.warn("No stage has been provided for rendering templates, using 'default'.")
-
         Logger.info("Loading parameters...")
         parameters = Parameters.list(stage, uninherited=False)
 
